Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/fulltextsearch.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/lib/Model
diff options
context:
space:
mode:
authorMaxence Lange <maxence@artificial-owl.com>2018-01-06 17:04:06 +0300
committerMaxence Lange <maxence@artificial-owl.com>2018-01-06 17:04:06 +0300
commite2a32c728a64ca9d0bbbd2820223bc4f7525d5ab (patch)
tree66f6c46949c6c263526d9eecf9507fb0876678ab /lib/Model
parent24fa7bc774eac26e6a3a9368b133540293e60783 (diff)
rename
Signed-off-by: Maxence Lange <maxence@artificial-owl.com>
Diffstat (limited to 'lib/Model')
-rw-r--r--lib/Model/DocumentAccess.php7
-rw-r--r--lib/Model/ExtendedBase.php9
-rw-r--r--lib/Model/ExtendedIndex.php9
-rw-r--r--lib/Model/ExtendedTick.php7
-rw-r--r--lib/Model/Index.php7
-rw-r--r--lib/Model/IndexDocument.php9
-rw-r--r--lib/Model/ProviderIndexes.php7
-rw-r--r--lib/Model/Runner.php19
-rw-r--r--lib/Model/SearchRequest.php10
-rw-r--r--lib/Model/SearchResult.php9
-rw-r--r--lib/Model/Tick.php7
11 files changed, 45 insertions, 55 deletions
diff --git a/lib/Model/DocumentAccess.php b/lib/Model/DocumentAccess.php
index c2b542a..7c61b53 100644
--- a/lib/Model/DocumentAccess.php
+++ b/lib/Model/DocumentAccess.php
@@ -1,12 +1,12 @@
<?php
/**
* FullNextSearch - Full Text Search your Nextcloud.
*
* This file is licensed under the Affero General Public License version 3 or
* later. See the COPYING file.
*
* @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2017
+ * @copyright 2018
* @license GNU AGPL version 3 or any later version
*
* This program is free software: you can redistribute it and/or modify
@@ -22,10 +22,9 @@
* You should have received a copy of the GNU Affero General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
- *
*/
-namespace OCA\FullNextSearch\Model;
+namespace OCA\FullTextSearch\Model;
class DocumentAccess implements \JsonSerializable {
@@ -1,12 +1,12 @@
<?php
/**
- * FullNextSearch - Full Text Search your Nextcloud.
+ * FullTextSearch - Full text search framework for Nextcloud
*
* This file is licensed under the Affero General Public License version 3 or
diff --git a/lib/Model/ExtendedBase.php b/lib/Model/ExtendedBase.php
index 6f7f3da..2b5c25e 100644
--- a/lib/Model/ExtendedBase.php
+++ b/lib/Model/ExtendedBase.php
@@ -1,12 +1,12 @@
<?php
/**
* FullNextSearch - Full Text Search your Nextcloud.
*
* This file is licensed under the Affero General Public License version 3 or
* later. See the COPYING file.
*
* @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2017
+ * @copyright 2018
* @license GNU AGPL version 3 or any later version
*
* This program is free software: you can redistribute it and/or modify
@@ -22,14 +22,13 @@
* You should have received a copy of the GNU Affero General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
- *
*/
-namespace OCA\FullNextSearch\Model;
+namespace OCA\FullTextSearch\Model;
use OC\Core\Command\Base;
-use OCA\FullNextSearch\Exceptions\InterruptException;
+use OCA\FullTextSearch\Exceptions\InterruptException;
use Symfony\Component\Console\Output\OutputInterface;
@@ -1,12 +1,12 @@
<?php
/**
- * FullNextSearch - Full Text Search your Nextcloud.
+ * FullTextSearch - Full text search framework for Nextcloud
*
* This file is licensed under the Affero General Public License version 3 or
diff --git a/lib/Model/ExtendedIndex.php b/lib/Model/ExtendedIndex.php
index 9dea110..a26377e 100644
--- a/lib/Model/ExtendedIndex.php
+++ b/lib/Model/ExtendedIndex.php
@@ -1,12 +1,12 @@
<?php
/**
* FullNextSearch - Full Text Search your Nextcloud.
*
* This file is licensed under the Affero General Public License version 3 or
* later. See the COPYING file.
*
* @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2017
+ * @copyright 2018
* @license GNU AGPL version 3 or any later version
*
* This program is free software: you can redistribute it and/or modify
@@ -21,12 +21,11 @@
*
* You should have received a copy of the GNU Affero General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
- *
+ *
*/
-namespace OCA\FullNextSearch\Model;
+namespace OCA\FullTextSearch\Model;
class ExtendedIndex extends Index {
@@ -1,12 +1,12 @@
<?php
/**
- * FullNextSearch - Full Text Search your Nextcloud.
+ * FullTextSearch - Full text search framework for Nextcloud
*
* This file is licensed under the Affero General Public License version 3 or
diff --git a/lib/Model/ExtendedTick.php b/lib/Model/ExtendedTick.php
index 806bdf9..8c70c6c 100644
--- a/lib/Model/ExtendedTick.php
+++ b/lib/Model/ExtendedTick.php
@@ -1,12 +1,12 @@
<?php
/**
* FullNextSearch - Full Text Search your Nextcloud.
*
* This file is licensed under the Affero General Public License version 3 or
* later. See the COPYING file.
*
* @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2017
+ * @copyright 2018
* @license GNU AGPL version 3 or any later version
*
* This program is free software: you can redistribute it and/or modify
@@ -22,11 +22,10 @@
* You should have received a copy of the GNU Affero General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
- *
*/
-namespace OCA\FullNextSearch\Model;
+namespace OCA\FullTextSearch\Model;
class ExtendedTick extends Tick {
@@ -1,12 +1,12 @@
<?php
/**
- * FullNextSearch - Full Text Search your Nextcloud.
+ * FullTextSearch - Full text search framework for Nextcloud
*
* This file is licensed under the Affero General Public License version 3 or
diff --git a/lib/Model/Index.php b/lib/Model/Index.php
index 4cf1b2c..c9525ca 100644
--- a/lib/Model/Index.php
+++ b/lib/Model/Index.php
@@ -1,12 +1,12 @@
<?php
/**
* FullNextSearch - Full Text Search your Nextcloud.
*
* This file is licensed under the Affero General Public License version 3 or
* later. See the COPYING file.
*
* @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2017
+ * @copyright 2018
* @license GNU AGPL version 3 or any later version
*
* This program is free software: you can redistribute it and/or modify
@@ -22,10 +22,9 @@
* You should have received a copy of the GNU Affero General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
- *
*/
-namespace OCA\FullNextSearch\Model;
+namespace OCA\FullTextSearch\Model;
class Index implements \JsonSerializable {
@@ -1,12 +1,12 @@
<?php
/**
- * FullNextSearch - Full Text Search your Nextcloud.
+ * FullTextSearch - Full text search framework for Nextcloud
*
* This file is licensed under the Affero General Public License version 3 or
diff --git a/lib/Model/IndexDocument.php b/lib/Model/IndexDocument.php
index 01fabcb..5f27b76 100644
--- a/lib/Model/IndexDocument.php
+++ b/lib/Model/IndexDocument.php
@@ -1,12 +1,12 @@
<?php
/**
* FullNextSearch - Full Text Search your Nextcloud.
*
* This file is licensed under the Affero General Public License version 3 or
* later. See the COPYING file.
*
* @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2017
+ * @copyright 2018
* @license GNU AGPL version 3 or any later version
*
* This program is free software: you can redistribute it and/or modify
@@ -21,11 +21,10 @@
*
* You should have received a copy of the GNU Affero General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
- *
+ *
*/
-namespace OCA\FullNextSearch\Model;
+namespace OCA\FullTextSearch\Model;
class IndexDocument implements \JsonSerializable {
@@ -1,12 +1,12 @@
<?php
/**
- * FullNextSearch - Full Text Search your Nextcloud.
+ * FullTextSearch - Full text search framework for Nextcloud
*
* This file is licensed under the Affero General Public License version 3 or
diff --git a/lib/Model/ProviderIndexes.php b/lib/Model/ProviderIndexes.php
index dc838c2..8b747fc 100644
--- a/lib/Model/ProviderIndexes.php
+++ b/lib/Model/ProviderIndexes.php
@@ -1,12 +1,12 @@
<?php
/**
* FullNextSearch - Full Text Search your Nextcloud.
*
* This file is licensed under the Affero General Public License version 3 or
* later. See the COPYING file.
*
* @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2017
+ * @copyright 2018
* @license GNU AGPL version 3 or any later version
*
* This program is free software: you can redistribute it and/or modify
@@ -22,11 +22,10 @@
* You should have received a copy of the GNU Affero General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
- *
*/
-namespace OCA\FullNextSearch\Model;
+namespace OCA\FullTextSearch\Model;
class ProviderIndexes {
@@ -1,12 +1,12 @@
<?php
/**
- * FullNextSearch - Full Text Search your Nextcloud.
+ * FullTextSearch - Full text search framework for Nextcloud
*
* This file is licensed under the Affero General Public License version 3 or
diff --git a/lib/Model/Runner.php b/lib/Model/Runner.php
index cf6c15b..7dea51f 100644
--- a/lib/Model/Runner.php
+++ b/lib/Model/Runner.php
@@ -1,12 +1,12 @@
<?php
/**
* FullNextSearch - Full Text Search your Nextcloud.
*
* This file is licensed under the Affero General Public License version 3 or
* later. See the COPYING file.
*
* @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2017
+ * @copyright 2018
* @license GNU AGPL version 3 or any later version
*
* This program is free software: you can redistribute it and/or modify
@@ -21,19 +21,18 @@
*
* You should have received a copy of the GNU Affero General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
- *
+ *
*/
-namespace OCA\FullNextSearch\Model;
+namespace OCA\FullTextSearch\Model;
use Exception;
-use OCA\FullNextSearch\Exceptions\InterruptException;
-use OCA\FullNextSearch\Exceptions\RunnerAlreadyUpException;
-use OCA\FullNextSearch\Exceptions\TickDoesNotExistException;
-use OCA\FullNextSearch\Exceptions\TickIsNotAliveException;
-use OCA\FullNextSearch\Service\RunningService;
+use OCA\FullTextSearch\Exceptions\InterruptException;
+use OCA\FullTextSearch\Exceptions\RunnerAlreadyUpException;
+use OCA\FullTextSearch\Exceptions\TickDoesNotExistException;
+use OCA\FullTextSearch\Exceptions\TickIsNotAliveException;
+use OCA\FullTextSearch\Service\RunningService;
use Symfony\Component\Console\Output\OutputInterface;
@@ -1,12 +1,12 @@
<?php
/**
- * FullNextSearch - Full Text Search your Nextcloud.
+ * FullTextSearch - Full text search framework for Nextcloud
*
* This file is licensed under the Affero General Public License version 3 or
diff --git a/lib/Model/SearchRequest.php b/lib/Model/SearchRequest.php
index 31a25a2..4c535eb 100644
--- a/lib/Model/SearchRequest.php
+++ b/lib/Model/SearchRequest.php
@@ -1,12 +1,12 @@
<?php
/**
* FullNextSearch - Full Text Search your Nextcloud.
*
* This file is licensed under the Affero General Public License version 3 or
* later. See the COPYING file.
*
* @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2017
+ * @copyright 2018
* @license GNU AGPL version 3 or any later version
*
* This program is free software: you can redistribute it and/or modify
@@ -21,12 +21,12 @@
*
* You should have received a copy of the GNU Affero General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
- *
+ *
*/
-namespace OCA\FullNextSearch\Model;
+namespace OCA\FullTextSearch\Model;
-use OCA\FullNextSearch\Service\MiscService;
+use OCA\FullTextSearch\Service\MiscService;
class SearchRequest implements \JsonSerializable {
@@ -1,12 +1,12 @@
<?php
/**
- * FullNextSearch - Full Text Search your Nextcloud.
+ * FullTextSearch - Full text search framework for Nextcloud
*
* This file is licensed under the Affero General Public License version 3 or
diff --git a/lib/Model/SearchResult.php b/lib/Model/SearchResult.php
index 12ad75e..fdd739e 100644
--- a/lib/Model/SearchResult.php
+++ b/lib/Model/SearchResult.php
@@ -1,12 +1,12 @@
<?php
/**
* FullNextSearch - Full Text Search your Nextcloud.
*
* This file is licensed under the Affero General Public License version 3 or
* later. See the COPYING file.
*
* @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2017
+ * @copyright 2018
* @license GNU AGPL version 3 or any later version
*
* This program is free software: you can redistribute it and/or modify
@@ -22,12 +22,11 @@
* You should have received a copy of the GNU Affero General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
- *
*/
-namespace OCA\FullNextSearch\Model;
+namespace OCA\FullTextSearch\Model;
-use OCA\FullNextSearch\INextSearchProvider;
+use OCA\FullTextSearch\INextSearchProvider;
class SearchResult implements \JsonSerializable {
@@ -1,12 +1,12 @@
<?php
/**
- * FullNextSearch - Full Text Search your Nextcloud.
+ * FullTextSearch - Full text search framework for Nextcloud
*
* This file is licensed under the Affero General Public License version 3 or
diff --git a/lib/Model/Tick.php b/lib/Model/Tick.php
index 676e03f..865bb86 100644
--- a/lib/Model/Tick.php
+++ b/lib/Model/Tick.php
@@ -1,12 +1,12 @@
<?php
/**
* FullNextSearch - Full Text Search your Nextcloud.
*
* This file is licensed under the Affero General Public License version 3 or
* later. See the COPYING file.
*
* @author Maxence Lange <maxence@artificial-owl.com>
- * @copyright 2017
+ * @copyright 2018
* @license GNU AGPL version 3 or any later version
*
* This program is free software: you can redistribute it and/or modify
@@ -22,11 +22,10 @@
* You should have received a copy of the GNU Affero General Public License
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
- *
*/
-namespace OCA\FullNextSearch\Model;
+namespace OCA\FullTextSearch\Model;
class Tick {
@@ -1,12 +1,12 @@
<?php
/**
- * FullNextSearch - Full Text Search your Nextcloud.
+ * FullTextSearch - Full text search framework for Nextcloud
*
* This file is licensed under the Affero General Public License version 3 or